import { ITekConfig } from '@zeedhi/teknisa-components-common';
import prodEnvironment from './prodEnvironment.json';
import devEnvironment from './devEnvironment.json';

export interface TecDietMask extends Object {
  pattern: string;
  nivelMax?: number;
}

export interface TecDietCurrencyMask extends Object {
  currencySymbol: string;
  decimalPlaces: string | number;
  decimalCharacter: string;
  digitGroupSeparator: string;
}

const cdpictprod: string | null = localStorage.getItem('CDPICTPROD');
const cdpictprat: string | null = localStorage.getItem('CDPICTPRAT');
const displayFormat = localStorage.getItem('DATEFORMAT') || 'DD/MM/YYYY';
const currencySymbol = localStorage.getItem('CURRENCY') || 'R$';
const decimalPlaces = '5';
const separador = localStorage.getItem('LOGIN_SEPARATOR') || '.,';
const decimalCharacter = separador.substring(2, 1) || ',';
const digitGroupSeparator = separador.substring(0, 1) || '.';

const cnpjMask: TecDietMask = {
  pattern: 'NN.NNN.NNN/NNNN-NN',
};

const cpfMask: TecDietMask = {
  pattern: 'NNN.NNN.NNN-NN',
};

const productMask: TecDietMask = {
  pattern: cdpictprod ? cdpictprod.replace(/[0-9a-zA-Z!@#$%^&*()_+]/g, 'N') : 'N.NN.NN.NNN.NN',
  nivelMax: cdpictprod ? cdpictprod.split('.').length : 5,
};
const plateMask: TecDietMask = {
  pattern: cdpictprat ? cdpictprat.replace(/[0-9a-zA-Z!@#$%^&*()_+]/g, 'N') : 'NN.NN.NN.NNN',
  nivelMax: cdpictprat ? cdpictprat.split('.').length : 4,
};

const env = process.env.NODE_ENV === 'production' ? prodEnvironment : devEnvironment;

const config: ITekConfig = {
  language: 'pt-BR',
  dateFormat: 'YYYY-MM-DD',
  displayFormat,
  displayDateTimeFormat: 'DD/MM/YYYY HH:mm',
  dateTimeFormat: 'YYYY-MM-DDTHH:mm:ss',
  homeUrl: '/',
  monthFormat: 'MM/YY',
  monthDisplayFormat: 'MMM/YY',
  endPoint: env.endPoint,
  metadataEndPoint: env.metadataEndPoint,
  env: {
    nodeEnv: process.env.NODE_ENV,
    product: env.product,
    baseUrl: env.baseUrl,
    modules: env.modules,
    loginRoutePath: env.modules.login.routePath,
    loginBackgroundImgUrl: env.modules.login.backgroundImgUrl,
    loginEndPoint: env.modules.login.endPoint,
  },
  saveGridLayoutsEndPoint: env.saveGridLayoutsEndPoint,
  loadGridLayoutsEndPoint: env.loadGridLayoutsEndPoint,
  masks: {
    numberMask: {
      decimalCharacter: `${decimalCharacter}`,
      digitGroupSeparator: `${digitGroupSeparator}`,
      currencySymbol: '',
      decimalPlaces: `${decimalPlaces}`,
    },
    currencyMask: {
      decimalCharacter: `${decimalCharacter}`,
      digitGroupSeparator: `${digitGroupSeparator}`,
      currencySymbol: `${currencySymbol}`,
      decimalPlaces: `${decimalPlaces}`,
    },
    cnpjMask,
    cpfMask,
    productMask,
    plateMask,
  },
};

export default config;
