import {
  Config, Singleton, dayjs as moment, I18n, IDictionary, Http, Loader,
} from '@zeedhi/core';
import { LoadingService } from '@zeedhi/common';
import { TecDietCurrencyMask, TecDietMask } from '@/config';

@Singleton
export class LoginController {
  public appController = Loader.getInstance('AppController');

  get logo() {
    return Config.env.product.logoUrl;
  }

  get logoMessage() {
    return Config.env.product.name;
  }

  get backgroundImgUrl() {
    const url = Config.env.loginBackgroundImgUrl;
    return `url(${url})`;
  }

  get endPoint() {
    return Config.env.loginEndPoint;
  }

  public setLocalStorageUser(userData: IDictionary) {
    if (userData) {
      LoadingService.show(' ');
      Http.post('/userInfo', { requestType: 'Row', row: {} }).then((result: IDictionary) => {
        const userInfo = result.data?.dataset?.userInfo;
        if (userInfo) {
          localStorage.setItem('CDOPERADOR', userData.CDOPERADOR);
          localStorage.setItem('NMFILIALLOGADA', userInfo.NMFILIAL);
          localStorage.setItem('NMACESSO', userInfo.NMACESSO);
          localStorage.setItem('CDPICTPROD', userInfo.CDPICTPROD);
          localStorage.setItem('CDPICTPRAT', userInfo.CDPICTPRAT);
          (Config.masks.productMask as TecDietMask).pattern = userInfo.CDPICTPROD
            ? userInfo.CDPICTPROD.replace(/[0-9a-zA-Z!@#$%^&*()_+]/g, 'N')
            : 'N.NN.NN.NNN.NN';

          (Config.masks.productMask as TecDietMask).nivelMax = userInfo.CDPICTPROD
            ? userInfo.CDPICTPROD.split('.').length
            : 5;
        }
      }).finally(() => {
        LoadingService.hide();
      });
    }

    this.setLanguage();

    localStorage.setItem('DATEFORMAT', this.appController.getFormatLocale());
    Config.displayFormat = this.appController.getFormatLocale();

    const lang = this.appController.getLanguage();
    const currency: string = this.appController.metaCurrency[lang];
    const locale: string = this.appController.metaLanguages[lang];
    const separador = localStorage.getItem('LOGIN_SEPARATOR') || '.,';

    (Config.masks.currencyMask as TecDietCurrencyMask)
      .currencySymbol = this.appController.getCurrencySymbol(locale, currency);
    (Config.masks.currencyMask as TecDietCurrencyMask).decimalCharacter = separador.substring(2, 1) || ',';
    (Config.masks.currencyMask as TecDietCurrencyMask).digitGroupSeparator = separador.substring(0, 1) || '.';

    (Config.masks.numberMask as TecDietCurrencyMask).decimalCharacter = separador.substring(2, 1) || ',';
    (Config.masks.numberMask as TecDietCurrencyMask).digitGroupSeparator = separador.substring(0, 1) || '.';

    localStorage.setItem('CURRENCY', (Config.masks.currencyMask as TecDietCurrencyMask).currencySymbol);
  }

  private setLanguage() {
    const lang = this.appController.getLanguage();
    I18n.changeLanguage(this.appController.metaLanguages[lang]);
    moment.locale(lang.substring(0, 2));
  }
}
