import { Metadata, Http } from '@zeedhi/core';

import {
  GridEditable, ModalService, Modal, DialogService, Form, LoadingService,
} from '@zeedhi/common';

export class OccurrenceEnteralParenteralController {
  private modalInCreation = false;

  private modalIncluir!: Modal;

  public startGrid() {
    const grid = Metadata.getInstance<GridEditable>('dih51500-grid');
    grid.datasource.get();
  }

  public dialogErroUniqueKey() {
    DialogService.show({
      name: 'dialogErroUniqueKeyOcorrencia',
      type: 'error',
      title: 'td::atencao',
      text: 'td::registroCodigoExiste',
      buttons: [
        {
          name: 'fechar',
          component: 'ZdButton',
          label: 'td::fechar',
          events: { click: () => DialogService.hide() },
        },
      ],
    });
  }

  public addOccurrenceEnteralParenteral() {
    const formModal = Metadata.getInstance<Form>('dih51500_containerModalForm');
    const validacaoForm = formModal.validate();

    if (validacaoForm) {
      const grid = Metadata.getInstance<GridEditable>('dih51500-grid');
      const existeUniqueKey = grid.datasource.data.find((cod) => cod.CDTPOCORINFU === formModal.value.CDTPOCORINFU);

      if (existeUniqueKey) {
        this.dialogErroUniqueKey();
      } else {
        LoadingService.show('Processando...');
        const dados = [{
          CDTPOCORINFU: formModal.value.CDTPOCORINFU,
          NMTPOCORINFU: formModal.value.NMTPOCORINFU,
          __is_new: true,
        }];

        Http.post('/crud/save', { editedRows: dados, dataSourceName: 'occurrenceEnteralParenteral' }).then(async () => {
          await grid.datasource.get();
          this.closeIncludeModal();
        }).finally(() => {
          LoadingService.hide();
        });
      }
    }
  }

  public saveEditOccurrenceEnteralParenteral() {
    LoadingService.show('Processando...');
    const grid = Metadata.getInstance<GridEditable>('dih51500-grid');
    const editedRows = grid.getEditedRows();

    /* eslint-disable no-underscore-dangle */
    editedRows.forEach((row) => {
      if (!row.__is_new) row.__is_new = false;
    });
    /* eslint-enable no-underscore-dangle */

    Http.post('/crud/save', { editedRows, dataSourceName: 'occurrenceEnteralParenteral' }).then(async () => {
      await grid.cancelEditedRows();
      await grid.datasource.get();
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public confirmRemoveRow() {
    DialogService.show({
      name: 'dialogExclusaoOcorrencia',
      type: 'warning',
      title: 'td::excluirRegistro',
      text: 'td::desejaExcluir',
      buttons: [
        {
          name: 'no',
          component: 'ZdButton',
          label: 'td::nao',
          events: { click: () => DialogService.hide() },
          outline: true,
        },
        {
          name: 'yes',
          component: 'ZdButton',
          label: 'td::sim',
          events: { click: () => this.removeOccurrenceEnteralParenteral() },
        },
      ],
    });
  }

  public removeOccurrenceEnteralParenteral() {
    LoadingService.show('Processando...');
    const grid = Metadata.getInstance<GridEditable>('dih51500-grid');
    const checkedRows = grid.selectedRows;

    Http.post('/crud/delete', { checkedRows, dataSourceName: 'occurrenceEnteralParenteral' }).then(async () => {
      DialogService.hide();

      await grid.cancelEditedRows();
      await grid.datasource.get();
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public async createIncludeModal() {
    this.modalIncluir = await ModalService.createFromJson(
      '/parametrizacao/tabelas/modals/dih51500_occurrence_enteral_parenteral_modal', true,
    );
  }

  public openIncludeModal() {
    const grid: GridEditable = Metadata.getInstance('dih51500-grid');

    if (grid) {
      this.createIncludeModal().then(() => {
        this.modalIncluir.show();
      });
    }
  }

  public closeIncludeModal() {
    this.modalIncluir.hide();
    this.modalIncluir.destroy();
  }
}
