import { Metadata, Http } from '@zeedhi/core';

import {
  GridEditable, ModalService, Modal, DialogService, Form, LoadingService,
} from '@zeedhi/common';

export class PadraoInternacaoController {
  private modalInCreation = false;

  private modalIncluir!: Modal;

  public iniciaGrid() {
    const grid = Metadata.getInstance<GridEditable>('dih31000-grid');
    grid.datasource.get();
  }

  public dialogErroUniqueKey() {
    DialogService.show({
      name: 'erroPadraoInternacao',
      type: 'error',
      title: 'td::atencao',
      text: 'td::registroCodigoExiste',
      buttons: [
        {
          name: 'fechar',
          component: 'ZdButton',
          label: 'td::fechar',
          events: { click: () => DialogService.hide() },
        },
      ],
    });
  }

  public adicionarPadraoInternacao() {
    const formModal = Metadata.getInstance<Form>('containerModalForm');
    const validacaoForm = formModal.validate();
    if (validacaoForm) {
      const grid = Metadata.getInstance<GridEditable>('dih31000-grid');
      const existeUniqueKey = grid.datasource.data.find((cod) => cod.CDSERPADDIE === formModal.value.CDSERPADDIE);
      if (existeUniqueKey) {
        this.dialogErroUniqueKey();
      } else {
        LoadingService.show('Processando...');
        const dados = [{
          CDSERPADDIE: formModal.value.CDSERPADDIE,
          NMSERPADDIE: formModal.value.NMSERPADDIE,
          __is_new: true,
        }];
        Http.post('/crud/save', { editedRows: dados, dataSourceName: 'healthInsurance' }).then(async () => {
          await grid.datasource.get();
          this.fechaModalIncluir();
        }).finally(() => {
          LoadingService.hide();
        });
      }
    }
  }

  public salvarEdicao() {
    LoadingService.show('Processando...');
    const grid = Metadata.getInstance<GridEditable>('dih31000-grid');
    const editedRows = grid.getEditedRows();
    /* eslint-disable no-underscore-dangle */
    editedRows.forEach((row) => {
      if (!row.__is_new) row.__is_new = false;
    });
    /* eslint-enable no-underscore-dangle */
    Http.post('/crud/save', { editedRows, dataSourceName: 'healthInsurance' }).then(async () => {
      await grid.cancelEditedRows();
      await grid.datasource.get();
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public confirmaExclusao() {
    DialogService.show({
      name: 'dialogExclusaoPadraonternacao',
      type: 'warning',
      title: 'td::excluirRegistro',
      text: 'td::desejaExcluir',
      buttons: [
        {
          name: 'no',
          component: 'ZdButton',
          label: 'td::nao',
          events: { click: () => DialogService.hide() },
          outline: true,
        },
        {
          name: 'yes',
          component: 'ZdButton',
          label: 'td::sim',
          events: { click: () => this.excluirRegistro() },
        },
      ],
    });
  }

  public excluirRegistro() {
    LoadingService.show('Processando...');
    const grid = Metadata.getInstance<GridEditable>('dih31000-grid');
    const checkedRows = grid.selectedRows;
    Http.post('/crud/delete', { checkedRows, dataSourceName: 'healthInsurance' }).then(async () => {
      DialogService.hide();
      await grid.cancelEditedRows();
      await grid.datasource.get();
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public async criaModalIncluir() {
    this.modalIncluir = await ModalService.createFromJson(
      '/parametrizacao/tabelas/modals/modal_dih31000_padrao_internacao', true,
    );
  }

  public abreModalIncluir() {
    const grid: GridEditable = Metadata.getInstance('dih31000-grid');
    if (grid) {
      this.criaModalIncluir().then(() => {
        this.modalIncluir.show();
      });
    }
  }

  public fechaModalIncluir() {
    this.modalIncluir.hide();
    this.modalIncluir.destroy();
  }
}
